#[non_exhaustive]pub enum Indent {
None,
Spaces(usize),
Tab,
}Expand description
How the output is indented.
See SerializerConfig::set_indent and SerializerConfig::set_pretty.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
No indentation, the value is written on a single line.
Spaces(usize)
Every entry on a line of its own, indented by the given number of spaces per level.
Tab
Every entry on a line of its own, indented by a tab per level.